@@ -1,6 +1,6 @@
 /* gdkwindow-quartz.c
  *
- * Copyright (C) 2005-2006 Imendio AB
+ * Copyright (C) 2005-2007 Imendio AB
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,7 +32,7 @@
 
 #include "gdkinternals.h"
 
-#include <config.h>
+#include "config.h"
 
 #define GDK_TYPE_GC_QUARTZ              (_gdk_gc_quartz_get_type ())
 #define GDK_GC_QUARTZ(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), GDK_TYPE_GC_QUARTZ, GdkGCQuartz))
@@ -102,6 +102,8 @@ extern GdkWindow *_gdk_root;
 
 extern GdkDragContext *_gdk_quartz_drag_source_context;
 
+#define GDK_WINDOW_IS_QUARTZ(win)        (GDK_IS_WINDOW_IMPL_QUARTZ (((GdkWindowObject *)win)->impl))
+
 /* Initialization */
 void _gdk_windowing_window_init  (void);
 void _gdk_events_init            (void);
@@ -134,28 +136,33 @@ void _gdk_quartz_colormap_get_rgba_from_pixel (GdkColormap *colormap,
 					       gfloat      *alpha);
 
 /* Window */
-GdkWindow *_gdk_quartz_window_find_child_by_point   (GdkWindow *toplevel,
-						     gint       x,
-						     gint       y,
-						     gint      *x_ret,
-						     gint      *y_ret);
+gboolean    _gdk_quartz_window_is_ancestor          (GdkWindow *ancestor,
+                                                     GdkWindow *window);
 gint       _gdk_quartz_window_get_inverted_screen_y (gint       y);
+GdkWindow *_gdk_quartz_window_find_child            (GdkWindow *window,
+						     gint       x,
+						     gint       y);
+void       _gdk_quartz_window_attach_to_parent      (GdkWindow *window);
+void       _gdk_quartz_window_detach_from_parent    (GdkWindow *window);
+void       _gdk_quartz_window_did_become_main       (GdkWindow *window);
+void       _gdk_quartz_window_did_resign_main       (GdkWindow *window);
+void       _gdk_quartz_window_debug_highlight       (GdkWindow *window,
+                                                     gint       number);
 
 /* Events */
-void         _gdk_quartz_events_update_focus_window   (GdkWindow *new_window,
-						       gboolean   got_focus);
-GdkWindow *  _gdk_quartz_events_get_mouse_window       (void);
-void         _gdk_quartz_events_update_mouse_window    (GdkWindow *window);
-void         _gdk_quartz_events_update_cursor          (GdkWindow *window);
-void         _gdk_quartz_events_send_map_events        (GdkWindow *window);
+typedef enum {
+  GDK_QUARTZ_EVENT_SUBTYPE_EVENTLOOP
+} GdkQuartzEventSubType;
+
+void         _gdk_quartz_events_update_focus_window    (GdkWindow *new_window,
+                                                        gboolean   got_focus);
+void         _gdk_quartz_events_send_map_event         (GdkWindow *window);
 GdkEventMask _gdk_quartz_events_get_current_event_mask (void);
 
-extern GdkWindow *_gdk_quartz_keyboard_grab_window;
-extern GdkWindow *_gdk_quartz_pointer_grab_window;
-
 /* Event loop */
-NSEvent *  _gdk_quartz_event_loop_get_current     (void);
-void       _gdk_quartz_event_loop_release_current (void);
+gboolean   _gdk_quartz_event_loop_check_pending (void);
+NSEvent *  _gdk_quartz_event_loop_get_pending   (void);
+void       _gdk_quartz_event_loop_release_event (NSEvent *event);
 
 /* FIXME: image */
 GdkImage *_gdk_quartz_image_copy_to_image (GdkDrawable *drawable,
@@ -173,5 +180,17 @@ gboolean     _gdk_quartz_keys_is_modifier (guint      keycode);
 
 /* Drawable */
 void        _gdk_quartz_drawable_finish (GdkDrawable *drawable);
+void        _gdk_quartz_drawable_flush  (GdkDrawable *drawable);
+
+/* Geometry */
+void        _gdk_quartz_window_scroll      (GdkWindow       *window,
+                                            gint             dx,
+                                            gint             dy);
+void        _gdk_quartz_window_queue_translation (GdkWindow *window,
+                                                  GdkRegion *area,
+                                                  gint       dx,
+                                                  gint       dy);
+gboolean    _gdk_quartz_window_queue_antiexpose  (GdkWindow *window,
+                                                  GdkRegion *area);
 
 #endif /* __GDK_PRIVATE_QUARTZ_H__ */
